@@ -1,6 +1,6 @@
 /*
  * ====================================================================
- * Copyright (c) 2002-2006 The RapidSvn Group.  All rights reserved.
+ * Copyright (c) 2002-2008 The RapidSvn Group.  All rights reserved.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -26,13 +26,17 @@
 #ifndef _SVNCPP_CLIENT_H_
 #define _SVNCPP_CLIENT_H_
 
-// Ignore MSVC 6 compiler warning: debug symbol truncated
+// Ignore MSVC 6 compiler warning
 #if defined (_MSC_VER) && _MSC_VER <= 1200
+// debug symbol truncated
 #pragma warning (disable: 4786)
+// C++ exception specification
+#pragma warning (disable: 4290)
 #endif
 
-// Ignore MSVC 7 compiler warning: C++ exception specification
-#if defined (_MSC_VER) && _MSC_VER > 1200 && _MSC_VER <= 1310
+// Ignore MSVC 7,8 compiler warnings
+#if defined (_MSC_VER) && _MSC_VER > 1200 && _MSC_VER <= 1400
+// C++ exception specification
 #pragma warning (disable: 4290)
 #endif
 
@@ -43,7 +47,6 @@
 #include <map>
 
 // svncpp
-#include "svncpp/check.hpp"
 #include "svncpp/context.hpp"
 #include "svncpp/exception.hpp"
 #include "svncpp/path.hpp"
@@ -57,14 +60,17 @@ namespace svn
 {
   // forward declarations
   class Context;
+  class DirEntry;
+  class Info;
   class Status;
   class Targets;
-  class DirEntry;
 
+  typedef std::vector<AnnotateLine> AnnotatedFile;
+  typedef std::vector<DirEntry> DirEntries;
+  typedef std::vector<Info> InfoVector;
   typedef std::vector<LogEntry> LogEntries;
   typedef std::vector<Status> StatusEntries;
-  typedef std::vector<DirEntry> DirEntries;
-  typedef std::vector<AnnotateLine> AnnotatedFile;
+
 
   // map of property names to values
   typedef std::map<std::string,std::string> PropertiesMap;
@@ -92,6 +98,12 @@ namespace svn
     const Context * 
     getContext () const;
 
+    /**
+     * @return returns the Client context
+     */
+    Context * 
+    getContext();
+
     /**
      * sets the client context
      * you have to make sure the old context
@@ -123,17 +135,6 @@ namespace svn
             const bool no_ignore = false,
             const bool ignore_externals = false) throw (ClientException);
 
-    /**
-     * Returns the status of a single file in the path.
-     *
-     * Throws an exception if an error occurs
-     *
-     * @param path File to gather status.
-     * @return a Status with Statis.isVersioned = FALSE
-     */
-    Status 
-    singleStatus (const char * path) throw (ClientException);
-
     /**
      * Executes a revision checkout.
      * @param moduleName name of the module to checkout.
@@ -151,7 +152,7 @@ namespace svn
               const Revision & revision, 
               bool recurse,
               bool ignore_externals = false,
-              const Revision & peg_revision = Revision ()) throw (ClientException);
+              const Revision & peg_revision = Revision::UNSPECIFIED) throw (ClientException);
   
     /**
      * relocate wc @a from to @a to
@@ -215,21 +216,6 @@ namespace svn
     void 
     add (const Path & path, bool recurse) throw (ClientException);
 
-    /**
-     * Updates the file or directory.
-     * @param path target file.
-     * @param revision the revision number to checkout. 
-     *                 Revision::HEAD will checkout the 
-     *                 latest revision.
-     * @param recurse recursively update.
-     * @exception ClientException
-     *
-     * @deprecated
-     */
-    svn_revnum_t 
-    update (const Path & path, const Revision & revision, 
-            bool recurse) throw (ClientException);
-
     /**
      * Updates the file or directory.
      * @param targets target files.
@@ -239,12 +225,20 @@ namespace svn
      * @param recurse recursively update.
      * @param ignore_externals don't affect external destinations.
      * @exception ClientException
+     *
+     * @return a vector with resulting revisions
      */
-    void
-    update2 (const Targets & targets,
-             const Revision & revision, 
-             bool recurse,
-             bool ignore_externals) throw (ClientException);
+    std::vector<svn_revnum_t>
+    update (const Targets & targets,
+            const Revision & revision, 
+            bool recurse,
+            bool ignore_externals) throw (ClientException);
+
+    svn_revnum_t
+    update (const Path & path,
+            const Revision & revision, 
+            bool recurse,
+            bool ignore_externals) throw (ClientException);
 
     /**
      * Retrieves the contents for a specific @a revision of
@@ -252,13 +246,14 @@ namespace svn
      *
      * @param path path of file or directory
      * @param revision revision to retrieve
-     * @param peg_revision peg revision to retrieve, by default is the latest one
+     * @param peg_revision peg revision to retrieve, 
+     *        by default is the latest one
      * @return contents of the file
      */
     std::string
     cat (const Path & path, 
          const Revision & revision,
-         const Revision & peg_revision = Revision ()) throw (ClientException);
+         const Revision & peg_revision = Revision::UNSPECIFIED) throw (ClientException);
 
 
     /**
@@ -281,7 +276,7 @@ namespace svn
     get (Path & dstPath, 
          const Path & path,
          const Revision & revision, 
-         const Revision & peg_revision = Revision ()) throw (ClientException);
+         const Revision & peg_revision = Revision::UNSPECIFIED) throw (ClientException);
 
 
     /**
@@ -340,15 +335,13 @@ namespace svn
      * is a URL then authentication is usually required, see Auth.
      * 
      * @param path
-     * @param message log message.
      * @exception ClientException
      */
     void 
-    mkdir (const Path & path, 
-           const char * message = "") throw (ClientException);
+    mkdir (const Path & path) throw (ClientException);
+
     void 
-    mkdir (const Targets & targets, 
-           const char * message = "") throw (ClientException);
+    mkdir (const Targets & targets) throw (ClientException);
 
     /**
      * Recursively cleans up a local directory, finishing any
@@ -366,22 +359,6 @@ namespace svn
     void 
     resolved (const Path & path, bool recurse) throw (ClientException);
 
-    /**
-     * Exports the contents of either a subversion repository into a 
-     * 'clean' directory (meaning a directory with no administrative 
-     * directories).
-     * @exception ClientException
-     * @param srcPath source path
-     * @param destPath a destination path that must not already exist.
-     * @param revision revision to use for the export
-     * @param force force export
-     */
-    svn_revnum_t
-    doExport (const Path & srcPath, 
-              const Path & destPath, 
-              const Revision & revision, 
-              bool force = false) throw (ClientException);
-
     /**
      * Export into file or directory TO_PATH from local or remote FROM_PATH
      * @param from_path path to import
@@ -396,14 +373,14 @@ namespace svn
      * @exception ClientException
      */
     void
-    doExport2 (const Path & from_path,
-               const Path & to_path,
-               const Revision & revision,
-               bool overwrite = false,
-               const Revision & peg_revision = Revision (),
-               bool ignore_externals = false,
-               bool recurse = true,
-               const char * native_eol = NULL) throw (ClientException);
+    doExport (const Path & from_path,
+              const Path & to_path,
+              const Revision & revision,
+              bool overwrite = false,
+              const Revision & peg_revision = Revision::UNSPECIFIED,
+              bool ignore_externals = false,
+              bool recurse = true,
+              const char * native_eol = NULL) throw (ClientException);
 
     /**
      * Update local copy to mirror a new url. This excapsulates the 
@@ -429,6 +406,11 @@ namespace svn
             const char * url,
             const char * message, 
             bool recurse) throw (ClientException);
+    void
+    import (const Path & path,
+            const Path & url,
+            const char * message,
+            bool recurse) throw (ClientException);
 
 
     /**
@@ -443,15 +425,25 @@ namespace svn
            bool notice_ancestry = false,
            bool dry_run = false) throw (ClientException);
 
+
     /**
-     * Retrieve information for the given path
-     * from the wc
+     * retrieve information about the given path
+     * or URL
      *
-     * @param path
-     * @return Entry
+     * @see Client::status
+     * @see Info
+     *
+     * @param pathOrUrl
+     * @param pegRevision
+     * @param revision
+     * @param recurse
      */
-    Entry
-    info (const char * path);
+    InfoVector
+    info (const Path & pathOrUrl,
+          bool recurse=false,
+          const Revision & revision = Revision::UNSPECIFIED,
+          const Revision & pegRevision = Revision::UNSPECIFIED) throw (ClientException);
+
 
     /**
      * Retrieve log information for the given path
@@ -504,32 +496,63 @@ namespace svn
           const bool noDiffDeleted) throw (ClientException);
 
     /**
-     * lists entries in @a pathOrUrl no matter whether local or
-     * repository
+     * Produce diff output which describes the delta between
+     * @a path1/@a revision1 and @a path2/@a revision2. @a path1,
+     * @a path2 can be either a working-copy path or a URL.
      *
-     * @remark Please do not use the method anymore. Since it
-     *         tries to return entries with absolute paths
-     *         it has to add @a pathOrUrl to the beginning of
-     *         the enrties. This works fine if @a pathOrUrl 
-     *         points to a directory. But if it point to a file
-     *         "file:///foo/bar.txt", the path of the returned 
-     *         entry will be "file:///foo/bar.txt/bar.txt".
-     *         Please use @a list instead.
+     * A ClientException will be thrown if either @a revision1 or
+     * @a revision2 has an `unspecified' or unrecognized `kind'.
      *
-     * @deprecated
-     *
-     * @see list
-     *
-     * @param pathOrUrl
-     * @param revision
-     * @param recurse
-     * @return a vector of directory entries, each
-     *         with an absolute path
+     * @param tmpPath prefix for a temporary directory needed by diff.
+     * Filenames will have ".tmp" and similar added to this prefix in
+     * order to ensure uniqueness.
+     * @param path1 path of the first file corresponding to @a revision1.
+     * @param path2 path of the first file corresponding to @a revision2.
+     * @param revision1 one of the revisions to check.
+     * @param revision2 the other revision.
+     * @param recurse whether the operation should be done recursively.
+     * @param ignoreAncestry whether the files will be checked for
+     * relatedness.
+     * @param noDiffDeleted if true, no diff output will be generated
+     * on deleted files.
+     * @return delta between the files
+     * @exception ClientException
      */
-    DirEntries
-    ls (const char * pathOrUrl,
-        svn_opt_revision_t * revision,
-        bool recurse) throw (ClientException);
+    std::string
+    diff (const Path & tmpPath, const Path & path1, const Path & path2,
+          const Revision & revision1, const Revision & revision2,
+          const bool recurse, const bool ignoreAncestry,
+          const bool noDiffDeleted) throw (ClientException);
+
+    /**
+     * Produce diff output which describes the delta of
+     * @a path/@a pegRevision between @a revision1 and @a revision2. 
+     * @a path can be either a working-copy path or a URL.
+     *
+     * A ClientException will be thrown if either @a revision1 or
+     * @a revision2 has an `unspecified' or unrecognized `kind'.
+     *
+     * @param tmpPath prefix for a temporary directory needed by diff.
+     * Filenames will have ".tmp" and similar added to this prefix in
+     * order to ensure uniqueness.
+     * @param path path of the file.
+     * @param pegRevision the peg revision to identify the path.
+     * @param revision1 one of the revisions to check.
+     * @param revision2 the other revision.
+     * @param recurse whether the operation should be done recursively.
+     * @param ignoreAncestry whether the files will be checked for
+     * relatedness.
+     * @param noDiffDeleted if true, no diff output will be generated
+     * on deleted files.
+     * @return delta between the files
+     * @exception ClientException
+     */
+    std::string
+    diff (const Path & tmpPath, const Path & path,
+          const Revision & pegRevision, const Revision & revision1, 
+	  const Revision & revision2, const bool recurse, 
+	  const bool ignoreAncestry, const bool noDiffDeleted) 
+          throw (ClientException);
 
     /**
      * lists entries in @a pathOrUrl no matter whether local or
@@ -677,6 +700,25 @@ namespace svn
                 bool force = false);
 
 
+    /**
+     * Add a single file into ignore list.
+	 *
+     * @param path path to the file 
+     * @exception ClientException
+	 * @see svn:ignore property description
+     */
+    void 
+    ignore (const Path & path) throw (ClientException);
+
+    /**
+     * Add files into ignore list.
+     *
+     * @param targets targets to treat as ignored 
+     * @exception ClientException
+	 * @see svn:ignore property description
+     */
+    void 
+    ignore (const Targets & targets) throw (ClientException);
   private:
     Context * m_context;
 
