@@ -1,6 +1,6 @@
 /*
  * ====================================================================
- * Copyright (c) 2002-2006 The RapidSvn Group.  All rights reserved.
+ * Copyright (c) 2002-2008 The RapidSvn Group.  All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -28,6 +28,7 @@
 
 // svncpp
 #include "svncpp/client.hpp"
+#include "svncpp/targets.hpp"
 
 // app
 #include "action_event.hpp"
@@ -37,7 +38,7 @@
 #include "utils.hpp"
 
 CheckoutAction::CheckoutAction (wxWindow * parent)
-  : Action (parent, _("Checkout"), GetBaseFlags ())
+  : Action (parent, _("Checkout"), 0)
 {
 }
 
@@ -100,7 +101,7 @@ CheckoutAction::Perform ()
 
   revnum = -1;
   // Did the user request a specific peg revision?:
-  if (svn::SUPPORTS_PEG && !m_data.NotSpecified)
+  if (!m_data.NotSpecified)
   {
     TrimString(m_data.PegRevision);
     if (!m_data.PegRevision.IsEmpty ())
@@ -116,7 +117,7 @@ CheckoutAction::Perform ()
   svn::Path repUrlUtf8 (PathUtf8 (m_data.RepUrl));
   svn::Path destFolderUtf8 (PathUtf8 (m_data.DestFolder));
 
-  bool ignoreExternals = svn::SUPPORTS_EXTERNALS ? m_data.IgnoreExternals : false;
+  bool ignoreExternals = m_data.IgnoreExternals;
 
   client.checkout (repUrlUtf8.c_str (), 
                    destFolderUtf8, 
@@ -133,6 +134,13 @@ CheckoutAction::Perform ()
  
   return true;
 }
+
+bool
+CheckoutAction::CheckStatusSel (const svn::StatusSel & statusSel)
+{
+  return true;
+}
+
 /* -----------------------------------------------------------------
  * local variables:
  * eval: (load-file "../rapidsvn-dev.el")
