@@ -1,6 +1,6 @@
 /*
  * ====================================================================
- * Copyright (c) 2002-2006 The RapidSvn Group.  All rights reserved.
+ * Copyright (c) 2002-2008 The RapidSvn Group.  All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -27,10 +27,9 @@
 #include "wx/wx.h"
 
 // svncpp
-#include "svncpp/check.hpp"
 #include "svncpp/client.hpp"
 #include "svncpp/pool.hpp"
-#include "svncpp/targets.hpp"
+#include "svncpp/status_selection.hpp"
 
 // app
 #include "commit_action.hpp"
@@ -39,7 +38,7 @@
 #include "utils.hpp"
 
 CommitAction::CommitAction (wxWindow * parent)
-  : Action (parent, _("Commit"), GetBaseFlags ())
+  : Action (parent, _("Commit"), 0)
 {
 }
 
@@ -70,16 +69,15 @@ CommitAction::Perform ()
 {
   svn::Client client (GetContext ());
 
-  const svn::Targets & targets = GetTargets ();
+  const svn::StatusSel & statusSel = GetStatusSel ();
 
   std::string messageUtf8 (LocalToUtf8 (m_message));
 
   svn::Pool pool;
 
-  bool keepLocks = svn::SUPPORTS_LOCK ? m_keepLocks : false;
-  long revision = 
-    client.commit (targets.array (pool), messageUtf8.c_str (),
-                   m_recursive, keepLocks);
+  svn_revnum_t revision = 
+    client.commit (statusSel.targets (), messageUtf8.c_str (),
+                   m_recursive, m_keepLocks);
 
   wxString str;
 
@@ -92,6 +90,21 @@ CommitAction::Perform ()
   return true;
 }
 
+bool
+CommitAction::CheckStatusSel (const svn::StatusSel & statusSel)
+{
+  if (0 == statusSel.size ())
+    return false;
+
+  if (statusSel.hasUnversioned ())
+    return false;
+
+  if (statusSel.hasUrl ())
+    return false;
+
+  return true;
+}
+
 /* -----------------------------------------------------------------
  * local variables:
  * eval: (load-file "../rapidsvn-dev.el")
