@@ -1,6 +1,6 @@
 /*
  * ====================================================================
- * Copyright (c) 2002-2006 The RapidSvn Group.  All rights reserved.
+ * Copyright (c) 2002-2008 The RapidSvn Group.  All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -38,7 +38,7 @@
 #include "utils.hpp"
 
 DeleteAction::DeleteAction (wxWindow * parent)
-  : Action (parent, _("Delete"), GetBaseFlags ())
+  : Action (parent, _("Delete"), UPDATE_TREE)
 {
 }
 
@@ -73,14 +73,19 @@ DeleteAction::Perform ()
   for (it=v.begin (); it!=v.end (); it++)
   {
     svn::Path path (*it);
-    svn::Status status (client.singleStatus (path.c_str ()));
-    wxString wxpath = Utf8ToLocal(path.c_str ());
 
     client.remove (path, m_force);
   }
 
   return true;
 }
+
+bool
+DeleteAction::CheckStatusSel (const svn::StatusSel & statusSel)
+{
+  return true;
+}
+
 /* -----------------------------------------------------------------
  * local variables:
  * eval: (load-file "../rapidsvn-dev.el")
