@@ -1,6 +1,6 @@
 /*
  * ====================================================================
- * Copyright (c) 2002-2006 The RapidSvn Group.  All rights reserved.
+ * Copyright (c) 2002-2008 The RapidSvn Group.  All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -31,7 +31,9 @@
 #include "svncpp/client.hpp"
 #include "svncpp/entry.hpp"
 #include "svncpp/exception.hpp"
+#include "svncpp/info.hpp"
 #include "svncpp/status.hpp"
+#include "svncpp/targets.hpp"
 #include "svncpp/url.hpp"
 
 // app
@@ -75,18 +77,6 @@ public:
     action->Trace (msg);
   }
 
-  /**
-   * retrieves the status information for a file
-   */
-  svn::Status 
-  getStatus (const svn::Path & path)
-  {
-    svn::Client client (GetContext ());
-    svn::Status status (client.singleStatus (path.c_str ()));
-
-    return status;
-  }
-
   /**
    * retrieves the revision information for a file
    */
@@ -120,21 +110,6 @@ public:
       return path;
   }
 
-  /** 
-   * Check the status of a file. Only regular
-   * versioned files will pass this check
-   */
-  bool
-  checkStatus (const svn::Status & status)
-  {
-    if (!status.isVersioned ())
-      return false;
-
-    if (status.entry ().kind () != svn_node_file)
-      return false;
-
-    return true;
-  }
 
   /**
    * performs the diff operation on a single path:
@@ -154,15 +129,6 @@ public:
   diffTarget (const svn::Path & path)
   {
     svn::Path dstFile1, dstFile2;
-    svn::Status status (getStatus (path));
-
-    if (!checkStatus (status))
-    {
-      wxString msg, wxpath (Utf8ToLocal (path.c_str ()));
-      msg.Printf (_("Skipped: %s"), wxpath.c_str());
-      Trace (msg);
-      return;
-    }
 
     switch (diffData.compareType)
     {
@@ -223,13 +189,13 @@ public:
 };
 
 DiffAction::DiffAction (wxWindow * parent)
-  : Action (parent, _("Diff"), GetBaseFlags ())
+  : Action (parent, _("Diff"), DONT_UPDATE)
 {
   m = new Data (this, parent);
 }
 
 DiffAction::DiffAction (wxWindow * parent, DiffData & data)
-  : Action (parent, _("Diff"), GetBaseFlags ())
+  : Action (parent, _("Diff"), DONT_UPDATE)
 {
   m = new Data (this, parent, data);
 }
@@ -269,7 +235,12 @@ DiffAction::Prepare ()
     }
     bool isRemote = svn::Url::isValid (target.c_str ());
 
-    DiffDlg dlg (GetParent ());
+    // If there is more than one target, don't set the
+    //  default URL
+    wxString defaultUrl (wxEmptyString);
+    if (GetTargets ().size () == 1)
+      defaultUrl = Utf8ToLocal (target.c_str ());
+    DiffDlg dlg (GetParent (), defaultUrl);
 
     size_t count = GetTargets ().size ();
 
@@ -317,6 +288,12 @@ DiffAction::Perform ()
   return true;
 }
 
+bool
+DiffAction::CheckStatusSel (const svn::StatusSel & statusSel)
+{
+  return true;
+}
+
 /* -----------------------------------------------------------------
  * local variables:
  * eval: (load-file "../rapidsvn-dev.el")
