@@ -1,6 +1,6 @@
 /*
  * ====================================================================
- * Copyright (c) 2002-2006 The RapidSvn Group.  All rights reserved.
+ * Copyright (c) 2002-2008 The RapidSvn Group.  All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -29,6 +29,7 @@
 // svncpp
 #include "svncpp/client.hpp"
 #include "svncpp/m_check.hpp"
+#include "svncpp/targets.hpp"
 
 // app
 #include "export_action.hpp"
@@ -37,7 +38,7 @@
 #include "utils.hpp"
 
 ExportAction::ExportAction (wxWindow * parent)
-  :Action (parent, _("Export"), GetBaseFlags ())
+  :Action (parent, _("Export"), DONT_UPDATE)
 {
 }
 
@@ -95,7 +96,7 @@ ExportAction::Perform ()
 
   revnum = -1;
   // Did the user request a specific peg revision?:
-  if (svn::SUPPORTS_PEG && !m_data.NotSpecified)
+  if (!m_data.NotSpecified)
   {
     TrimString(m_data.PegRevision);
     if (!m_data.PegRevision.IsEmpty ())
@@ -111,26 +112,20 @@ ExportAction::Perform ()
   svn::Path srcPathUtf8 (PathUtf8 (m_data.SrcPath));
   svn::Path destPathUtf8 (PathUtf8 (m_data.DestPath));
 
-  if (svn::SUPPORTS_EXTERNALS)
-  {
-    bool ignoreExternals = svn::SUPPORTS_EXTERNALS ? m_data.IgnoreExternals : false;
+  client.doExport (srcPathUtf8.c_str (), 
+                   destPathUtf8, 
+                   revision,
+                   m_data.Overwrite,
+                   pegRevision,
+                   m_data.IgnoreExternals,
+                   m_data.Recursive,
+                   m_data.Eol);
+  return true;
+}
 
-    client.doExport2 (srcPathUtf8.c_str (), 
-                      destPathUtf8, 
-                      revision,
-                      m_data.Overwrite,
-                      pegRevision,
-                      ignoreExternals,
-                      m_data.Recursive,
-                      m_data.Eol);
-  }
-  else
-  {
-    client.doExport (srcPathUtf8.c_str (), 
-                     destPathUtf8, 
-                     revision,
-                     m_data.Overwrite);
-  }
+bool
+ExportAction::CheckStatusSel (const svn::StatusSel & statusSel)
+{
   return true;
 }
 
