@@ -1,6 +1,6 @@
 /*
  * ====================================================================
- * Copyright (c) 2002-2006 The RapidSvn Group.  All rights reserved.
+ * Copyright (c) 2002-2008 The RapidSvn Group.  All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,14 +22,17 @@
  * history and logs, available at http://rapidsvn.tigris.org/.
  * ====================================================================
  */
-// svncpp
-#include "svncpp/url.hpp"
 
 // wx
 #include "wx/wx.h"
 #include "wx/filename.h"
 #include "wx/intl.h"
 
+// svncpp
+#include "svncpp/url.hpp"
+#include "svncpp/status_selection.hpp"
+
+
 // app
 #include "external_program_action.hpp"
 #include "action_event.hpp"
@@ -40,8 +43,9 @@
 
 ExternalProgramAction::ExternalProgramAction (
   wxWindow * parent, long verb_id, bool treat_as_folder) 
- : Action (parent, _("Execute"), GetBaseFlags ()), 
-   m_verb_id (verb_id), m_treat_as_folder (treat_as_folder),
+ : Action (parent, _("Execute"), UPDATE_LATER), 
+   m_verb_id (verb_id), 
+   m_treat_as_folder (treat_as_folder),
    m_parent (parent)
 {
 }
@@ -144,6 +148,21 @@ ExternalProgramAction::Perform ()
   return true;
 }
 
+bool
+ExternalProgramAction::CheckStatusSel (const svn::StatusSel & statusSel)
+{
+  // works with all kinds of files and dirs,
+  // but only ONE is allowed
+  if (1 != statusSel.size ())
+    return false;
+
+  // directories are allowed only local
+  if (statusSel.hasUrl () && statusSel.hasDirs ())
+    return false;
+
+  return true;
+}
+
 /* -----------------------------------------------------------------
  * local variables:
  * eval: (load-file "../rapidsvn-dev.el")
