@@ -1,6 +1,6 @@
 /*
  * ====================================================================
- * Copyright (c) 2002-2006 The RapidSvn Group.  All rights reserved.
+ * Copyright (c) 2002-2008 The RapidSvn Group.  All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -28,17 +28,21 @@
 // stl
 #include <exception>
 #include <map>
+#include <deque> 
+#include <algorithm>
 
 // wxWidgets
 #include "wx/wx.h"
 #include "wx/confbase.h"
 #include "wx/filename.h"
 #include "wx/imaglist.h"
+#include "wx/dnd.h"
 
 // svncpp
 #include "svncpp/client.hpp"
 #include "svncpp/entry.hpp"
-#include "svncpp/targets.hpp"
+#include "svncpp/status.hpp"
+#include "svncpp/status_selection.hpp"
 #include "svncpp/url.hpp"
 
 // app
@@ -51,6 +55,7 @@
 #include "rapidsvn_app.hpp"
 #include "rapidsvn_frame.hpp"
 #include "utils.hpp"
+#include "rapidsvn_drop_target.hpp"
 
 // Bitmaps
 #include "res/bitmaps/sort_down.png.h"
@@ -102,11 +107,11 @@ static const wxChar ConfigSortOrder[]        = wxT("/FileListCtrl/SortOrder");
 static const wxChar ConfigColumnWidthFmt[]   = wxT("/FileListCtrl/Column%sWidth");
 static const wxChar ConfigColumnVisibleFmt[] = wxT("/FileListCtrl/Column%sVisible");
 static const wxChar ConfigWithUpdate[]       = wxT("/FileListCtrl/WithUpdate");
-static const wxChar ConfigFlatView[]         = wxT("/FileListCtrl/FlatView");
 static const wxChar ConfigShowUnversioned[]  = wxT("/FileListCtrl/ShowUnversioned");
 static const wxChar ConfigIgnoreExternals[]  = wxT("/FileListCtrl/IgnoreExternals");
 static const wxChar ConfigIncludePath[]      = wxT("/FileListCtrl/IncludePath");
 static const wxChar ConfigSortAscending[]    = wxT("/FileListCtrl/SortAscending");
+static const wxChar ConfigShowIgnored[]      = wxT("/FileListCtrl/ShowIgnored");
 
 /**
  * test if the given status entry is a file or
@@ -460,18 +465,15 @@ CompareItems (svn::Status * ps1, svn::Status * ps2,
 {
   int res = 0;
 
-  size_t length1 (Utf8ToLocal (ps1->path ()).length ());
-  size_t length2 (Utf8ToLocal (ps2->path ()).length ());
-
   // Directories always precede files AND
   // Current working directory '.' always first
   if (IsDir (ps1) &&
-      (!IsDir (ps2) || (length1 <= RootPathLength)))
+      (!IsDir (ps2) || (Utf8ToLocal (ps1->path ()).length () <= RootPathLength)))
   {
     res = -1;
   }
   else if (IsDir (ps2) &&
-           (!IsDir (ps1) || (length2 <= RootPathLength)))
+           (!IsDir (ps1) || (Utf8ToLocal (ps2->path ()).length () <= RootPathLength)))
   {
     res = 1;
   }
@@ -647,6 +649,10 @@ public:
   bool WithUpdate;
   bool ShowUnversioned;
   bool IgnoreExternals;
+  bool ShowIgnored;
+  bool IsRelative;
+
+  svn::StatusSel statusSel;
 
   /**
    * This table holds information about image index in a image list.
@@ -692,7 +698,8 @@ FileListCtrl::Data::Data ()
     IncludePath (true), SortAscending (true),
     DirtyColumns (true), FlatMode (false),
     WithUpdate (false), ShowUnversioned (true),
-    IgnoreExternals (false)
+    IgnoreExternals (false), ShowIgnored(false),
+    IsRelative (false)
 {
   ImageListSmall = new wxImageList (16, 16, TRUE);
 
@@ -862,11 +869,15 @@ FileListCtrl::Data::CompareFunction (long item1, long item2, long sortData)
   svn::Status * ps2 = (svn::Status *) item2;
   Data *data = (Data *) (sortData);
 
+  // depening on absolute or relative we have to adapt the
+  // length we take for "."
+  size_t compareLength = data->IsRelative ? 0 : data->Path.length ();
+
   if (ps1 && ps2)
     return CompareItems (ps1, ps2, data->SortColumn,
                          data->SortAscending,
                          data->IncludePath,
-                         data->Path.length ());
+                         compareLength);
   else
     return 0;
 }
@@ -885,10 +896,10 @@ FileListCtrl::Data::ReadConfig ()
   SortAscending = config->Read (ConfigSortOrder, (long) 1) ? true : false;
 
   config->Read (ConfigIncludePath,     &IncludePath,     (bool) true);
-  config->Read (ConfigFlatView,        &FlatMode);
   config->Read (ConfigWithUpdate,      &WithUpdate);
   config->Read (ConfigShowUnversioned, &ShowUnversioned, (bool) true); 
   config->Read (ConfigIgnoreExternals, &IgnoreExternals, (bool) false);
+  config->Read (ConfigShowIgnored,     &ShowIgnored,     (bool) false);
 
   for (int col = 0; col < COL_COUNT; col++)
   {
@@ -915,10 +926,10 @@ FileListCtrl::Data::WriteConfig ()
   config->Write (ConfigSortColumn, (long) SortColumn);
   config->Write (ConfigIncludePath,       IncludePath);
   config->Write (ConfigSortOrder, (long) (SortAscending ? 1 : 0));
-  config->Write (ConfigFlatView,          FlatMode);
   config->Write (ConfigWithUpdate,        WithUpdate);
   config->Write (ConfigShowUnversioned,   ShowUnversioned);
   config->Write (ConfigIgnoreExternals,   IgnoreExternals);
+  config->Write (ConfigShowIgnored,       ShowIgnored);
 
   // loop through all the columns
   for (int col=0; col < COL_COUNT; col++)
@@ -937,6 +948,7 @@ BEGIN_EVENT_TABLE (FileListCtrl, wxListCtrl)
   EVT_LIST_ITEM_ACTIVATED (FILELIST_CTRL, FileListCtrl::OnDoubleClick)
   EVT_LIST_COL_CLICK (FILELIST_CTRL, FileListCtrl::OnColumnLeftClick)
   EVT_LIST_COL_END_DRAG (FILELIST_CTRL, FileListCtrl::OnColumnEndDrag)
+  EVT_LIST_BEGIN_DRAG (FILELIST_CTRL, FileListCtrl::OnBeginDrag)
   EVT_CONTEXT_MENU (FileListCtrl::OnContextMenu)
 END_EVENT_TABLE ()
 
@@ -976,6 +988,21 @@ FileListCtrl::RefreshFileList ()
 {
   svn::Path pathUtf8 (PathUtf8 (m->Path));
 
+  // store selection
+  std::deque<std::string> selection;
+  long i;
+  for (i=GetFirstSelected (); i != -1; i = GetNextSelected (i))
+  {
+    svn::Status const* status = reinterpret_cast<svn::Status const*>(GetItemData (i));
+    selection.push_back (status->path ());
+  }
+  std::sort (selection.begin (), selection.end ());
+  std::deque<std::string>::const_iterator selBegin = selection.begin (), selEnd = selection.end ();
+  // store scroll position
+  //int scrollPos = GetScrollPos (wxVERTICAL);
+  long topItem = GetTopItem ();
+  // freeze update to speed up processing.
+  Freeze ();
   // delete all the items in the list to display the new ones
   DeleteAllItems ();
 
@@ -983,25 +1010,56 @@ FileListCtrl::RefreshFileList ()
 
   wxLogStatus (_("Listing entries in '%s'"), m->Path.c_str ());
 
-  // Hide the list to speed up inserting
-  Hide ();
-
   svn::Client client (m->Context);
+  svn::StatusEntries statusSelector;
 
-  const svn::StatusEntries statusVector =
-    client.status (pathUtf8.c_str (), m->FlatMode, true, m->WithUpdate, false, m->IgnoreExternals);
+  // Workaround for issue 324 (only local+non-flat+update): 
+  //   we chdir to the requested dir and pass "." to svn
+  if (!pathUtf8.isUrl () && m->WithUpdate && !m->FlatMode)
+  {
+    m->IsRelative = true;
+    ::wxSetWorkingDirectory (m->Path);
+
+    // "" is the canonical expression for "."
+    statusSelector = client.status (
+      "", m->FlatMode, true, m->WithUpdate, 
+      m->ShowIgnored, m->IgnoreExternals);
+  }
+  else
+  {
+    m->IsRelative = false;
+    statusSelector = client.status (
+      pathUtf8.c_str (), m->FlatMode, true, m->WithUpdate, 
+      m->ShowIgnored, m->IgnoreExternals);
+  }
 
   svn::StatusEntries::const_iterator it;
-  for (it = statusVector.begin (); it != statusVector.end (); it++)
+  for (it = statusSelector.begin (); it != statusSelector.end (); it++)
   {
     const svn::Status & status = *it;
 
     CreateLables (status, pathUtf8);
+    // trying to restore selection
+    if (std::binary_search (selBegin, selEnd, status.path ()))
+    {
+      i=GetItemCount ()-1;
+      wxASSERT(i >= 0);
+      Select (i, true);
+    }
   }
 
   SortItems (Data::CompareFunction, (long) this->m);
 
-  Show ();
+  // reenable window update after Freeze()
+  Thaw();
+  // trying to restore scroll position, update must be enabled before
+  // because under WinXP call to ScrollList sometimes ignored without
+  // report about failure, mainly this related for relatively big lists
+  // and only for positions closer to the end of it
+  wxRect ir, cr;
+  GetItemRect (topItem, ir);
+  GetItemRect (GetTopItem (), cr);
+  ScrollList (0, ir.GetTop () - cr.GetTop ());
 
   wxLogStatus (_("Ready"),"");
 }
@@ -1010,24 +1068,49 @@ void
 FileListCtrl::CreateLables (const svn::Status & status, const svn::Path & basePathUtf8)
 {
   wxString values[COL_COUNT];
-  svn::Path fullPath (status.path ());
+  svn::Path fullPath;
+  bool isDot;;
+  svn::Path pathUtf8;
 
-  const size_t pathUtf8Length = basePathUtf8.length () + 1;
-  const bool isUrl (basePathUtf8.isUrl ());
+  if (m->IsRelative)
+  {
+    const char * path = status.path ();
+    pathUtf8 = path;
 
-  const bool isDot = (fullPath.length () <= pathUtf8Length);
-  svn::Path path;
+    fullPath = basePathUtf8;
 
-  if (isDot)
-    values[COL_NAME] = wxT(".");
+    // since we have a relative path, we know
+    // that an empty string means "."
+    isDot = '\0' == *path;
+    if (isDot)
+      values[COL_NAME] = wxT(".");
+    else
+    {
+      values[COL_NAME] = Utf8ToLocal (pathUtf8.basename ());
+      fullPath.addComponent (path);
+    }
+  }
   else
   {
-    path = (fullPath.substr (pathUtf8Length));
-    path = path.unescape ();
+    fullPath = status.path ();
+    
+    size_t basePathUtf8Length = basePathUtf8.length () + 1;
+    pathUtf8 = (fullPath.substr (basePathUtf8Length));
+    pathUtf8 = pathUtf8.unescape ();
 
-    values[COL_NAME] = Utf8ToLocal (path.basename ());
+    // if we have a basePathUtf8 like
+    // /home/foo/dir
+    // then we know /home/foo/dir means "."
+    // and /home/foo/dir/file1 is "file1"
+    isDot = fullPath.length () <= basePathUtf8Length;
+    if (isDot)
+      values[COL_NAME] = wxT(".");
+    else
+      values[COL_NAME] = Utf8ToLocal (pathUtf8.basename ());
   }
 
+  const bool isUrl (basePathUtf8.isUrl ());
+
   if (m->ColumnVisible[COL_PATH] || m->ColumnVisible[COL_EXTENSION])
   {
     std::string dir, filename, ext;
@@ -1038,9 +1121,9 @@ FileListCtrl::CreateLables (const svn::Status & status, const svn::Path & basePa
     else
     {
       if (isUrl)
-        values[COL_PATH] = Utf8ToLocal (path.c_str ());
+        values[COL_PATH] = Utf8ToLocal (pathUtf8.c_str ());
       else
-        values[COL_PATH] = Utf8ToLocal (path.native ());
+        values[COL_PATH] = Utf8ToLocal (pathUtf8.native ());
     }
 
    values[COL_EXTENSION] = Utf8ToLocal (ext);
@@ -1181,6 +1264,7 @@ FileListCtrl::GetSelectedItems () const
   return indx_arr;
 }
 
+#if 0
 const svn::Targets
 FileListCtrl::GetTargets () const
 {
@@ -1203,13 +1287,17 @@ FileListCtrl::GetTargets () const
 
   return svn::Targets (v);
 }
+#endif
 
-unsigned int
-FileListCtrl::GetSelectionActionFlags () const
+const svn::StatusSel &
+FileListCtrl::GetStatusSel () const
 {
+  m->statusSel.clear ();
+
   IndexArray arr = GetSelectedItems ();
-  size_t i, counter = 0;
-  unsigned int flags = 0;
+  size_t i;
+
+  m->statusSel.reserve (arr.GetCount ());
 
   for (i = 0; i < arr.GetCount (); i++)
   {
@@ -1219,34 +1307,10 @@ FileListCtrl::GetSelectionActionFlags () const
     if (status == 0)
       continue;
 
-    ++counter;
-    if (IsDir (status))
-    {
-      flags |= Action::IS_DIR;
-    }
-    if (svn::Url::isValid (status->path ()))
-    {
-      flags |= Action::RESPOSITORY_TYPE;
-    }
-    else
-    {
-      if (status->isVersioned ())
-      {
-        flags |= Action::VERSIONED_WC_TYPE;
-      }
-      else
-      {
-        flags |= Action::UNVERSIONED_WC_TYPE;
-      }
-    }
+    m->statusSel.push_back (*status);
   }
 
-  if (counter)
-  {
-    flags |= counter == 1 ? Action::SINGLE_TARGET : Action::MULTIPLE_TARGETS;
-  }
-
-  return flags;
+  return m->statusSel;
 }
 
 svn::Context *
@@ -1657,6 +1721,40 @@ FileListCtrl::SetIgnoreExternals (bool value)
   m->IgnoreExternals = value;
 }
 
+bool
+FileListCtrl::GetShowIgnored () const
+{
+  return m->ShowIgnored;
+}
+
+void
+FileListCtrl::SetShowIgnored (bool value)
+{
+  m->ShowIgnored = value;
+}
+
+void
+FileListCtrl::OnBeginDrag (wxListEvent & event)
+{
+  IndexArray arr = GetSelectedItems ();
+
+  wxFileDataObject data;
+  for (unsigned int i = 0; i < arr.GetCount (); i++)
+  {
+    const int index = arr.Item (i);
+    svn::Status * status = (svn::Status*)GetItemData (index);
+    data.AddFile (Utf8ToLocal (status->path ()));
+  }
+  
+  wxDropSource dropSource (this);
+  dropSource.SetData (data);
+  /** 
+   * @todo we dont seem to need result
+   * wxDragResult result = dropSource.DoDragDrop (true);
+   */
+  dropSource.DoDragDrop (true);
+}
+
 /* -----------------------------------------------------------------
  * local variables:
  * eval: (load-file "../rapidsvn-dev.el")
