@@ -1,6 +1,6 @@
 /*
  * ====================================================================
- * Copyright (c) 2002-2006 The RapidSvn Group.  All rights reserved.
+ * Copyright (c) 2002-2008 The RapidSvn Group.  All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -29,10 +29,6 @@
 #include "wx/listctrl.h"
 #include "wx/dynarray.h"
 
-// svncpp
-#include "svncpp/status.hpp"
-#include "svncpp/path.hpp"
-
 /**
  * Define an array of indexes of the selected items.
  */
@@ -45,9 +41,10 @@ WX_DEFINE_ARRAY (long, IndexArray);
 // forward declarations
 namespace svn
 {
-  class Targets;
   class Context;
   class Path;
+  class Status;
+  class StatusSel;
 }
 
 class FileListCtrl : public wxListView
@@ -219,21 +216,38 @@ public:
   void
   SetIgnoreExternals (bool value);
 
+  /**
+   * shall we display ignored file entries?
+   */
+  bool
+  GetShowIgnored () const;
+
+  void
+  SetShowIgnored (bool value);
+
   void RefreshFileList ();
   void RefreshFileList (const wxString & path);
 
   const IndexArray
   GetSelectedItems () const;
 
-  const svn::Targets
-  GetTargets () const;
+//TODO  const svn::Targets
+//TODO  GetTargets () const;
 
+  /** 
+   * the selected @ref Status instances
+   */
+  const svn::StatusSel &
+  GetStatusSel () const;
+
+#if 0
   /**
    * determine the properties of what has been selected
    * in terms of the relevant Action Flags.
    */
   unsigned int
   GetSelectionActionFlags () const;
+#endif
 
   svn::Context *
   GetContext () const;
@@ -264,6 +278,7 @@ private:
   void OnColumnLeftClick (wxListEvent & event);
   void OnColumnEndDrag (wxListEvent & event);
   void OnContextMenu (wxContextMenuEvent & event);
+  void OnBeginDrag (wxListEvent & event);
 
   void CreateLables (const svn::Status & status, const svn::Path & basePath);
 
