@@ -1,6 +1,6 @@
 /*
  * ====================================================================
- * Copyright (c) 2002-2006 The RapidSvn Group.  All rights reserved.
+ * Copyright (c) 2002-2008 The RapidSvn Group.  All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -31,12 +31,14 @@
 #include "wx/treectrl.h"
 #include "wx/confbase.h"
 #include "wx/hashmap.h"
+#include "wx/dnd.h"
 
 // svncpp
 #include "svncpp/context.hpp"
 #include "svncpp/client.hpp"
 #include "svncpp/dirent.hpp"
 #include "svncpp/status.hpp"
+#include "svncpp/status_selection.hpp"
 #include "svncpp/url.hpp"
 #include "svncpp/wc.hpp"
 
@@ -47,6 +49,8 @@
 #include "utils.hpp"
 #include "rapidsvn_app.hpp"
 #include "rapidsvn_frame.hpp"
+#include "rapidsvn_drop_target.hpp"
+#include "preferences.hpp"
 
 // bitmaps
 #include "res/bitmaps/computer.png.h"
@@ -92,6 +96,7 @@ IsValidSeparator (const wxString & sep)
   return ((sep == wxT("/")) || (sep == wxT("\\")));
 }
 
+
 /** 
  * data structure that contains information about
  * a single bookmark
@@ -147,6 +152,7 @@ public:
   BookmarkHashMap bookmarks;
   svn::Context defaultContext;
   bool useAuthCache;
+  svn::StatusSel statusSel;
 
   Data (wxWindow * window, const wxPoint & pos, const wxSize & size)
     : singleContext (0), window (window), listener (0), useAuthCache (true)
@@ -251,6 +257,20 @@ public:
     }
   }
 
+  const FolderItemData *
+  HitTest (const wxPoint & point) const
+  {
+    const wxTreeItemId id = treeCtrl->HitTest (point);
+
+    if(!id.IsOk ())
+      return 0;
+    else
+    {
+      FolderItemData* data = GetItemData (id);
+      return data;
+    }
+  }
+
   svn::Context *
   GetContext () 
   {
@@ -354,7 +374,7 @@ public:
 
     while (ok)
     {
-      if (filename != Utf8ToLocal (svn::Wc::ADM_DIR_NAME))
+      if (!svn::Wc::isAdmDir (LocalToUtf8 (filename).c_str ()))
         return true;
       ok = dir.GetNext (&filename);
     }
@@ -399,7 +419,15 @@ public:
         !treeCtrl->IsExpanded (treeCtrl->GetSelection ()))
     {
       if (code == '-' || code == WXK_LEFT)
-        treeCtrl->Collapse (treeCtrl->GetItemParent (treeCtrl->GetSelection ()));
+      {
+        wxTreeItemId parentId (
+          treeCtrl->GetItemParent(treeCtrl->GetSelection ()));
+
+        // make sure parentId is okay
+        // -> otherwise segfault (at least on wxGTK)
+        if (parentId.IsOk ())
+          treeCtrl->Collapse (parentId);
+      }
     }
     event.Skip ();
   }
@@ -459,12 +487,8 @@ public:
       try
       {
         const wxString& parentPath = parentData->getPath ();
-        svn::Path parentPathUtf8 (PathUtf8 (parentPath));
 
-        if (parentPathUtf8.isUrl ())
-          RefreshRepository (parentPath, parentId);
-        else
-          RefreshLocal (parentPath, parentId);
+        Refresh (parentPath, parentId);
       }
       catch (svn::ClientException & e)
       {
@@ -496,7 +520,7 @@ public:
   }
 
   void
-  RefreshLocal (const wxString & parentPath,
+  Refresh (const wxString & parentPath,
                 const wxTreeItemId & parentId)
   {
     // If the parent is already expanded, 
@@ -524,10 +548,20 @@ public:
       svn::Path filename (status.path ());
       wxString path (Utf8ToLocal (filename.native ()));
 
-      // Only display versioned directories and exclude parent itself
-      if (((status.entry ().kind () == svn_node_dir) ||
-           (status.textStatus () == svn_wc_status_external)) && 
-          (parentPath != path))
+      // Only display versioned directories
+      if ((status.entry ().kind () != svn_node_dir) &&
+          (status.textStatus () != svn_wc_status_external)) 
+        continue;
+           
+      if (parentPath == path)
+      {
+        // we update the information about the parent on
+        // every occassion
+        FolderItemData * data = GetItemData (parentId);
+        if (0 != data)
+          data->setStatus (status);
+      }
+      else
       {
         int image = FOLDER_IMAGE_FOLDER;
         int open_image = FOLDER_IMAGE_OPEN_FOLDER;
@@ -550,67 +584,27 @@ public:
           image = FOLDER_IMAGE_MODIFIED_FOLDER;
           open_image = FOLDER_IMAGE_MODIFIED_OPEN_FOLDER;
         }
+
         FolderItemData * data = new FolderItemData (
           FOLDER_TYPE_NORMAL, path, 
           Utf8ToLocal (filename.basename ()), 
           TRUE);
+        data->setStatus (status);
 
         wxTreeItemId newId = treeCtrl->AppendItem(
           parentId, 
           Utf8ToLocal (filename.basename ()), 
           image, image, data);
 
-        treeCtrl->SetItemHasChildren (newId, HasSubdirectories (path));
+        bool hasSubDirs = true;
+        if (!filename.isUrl ())
+          hasSubDirs = HasSubdirectories (path);
+        treeCtrl->SetItemHasChildren (newId, hasSubDirs);
         treeCtrl->SetItemImage (newId, open_image, wxTreeItemIcon_Expanded);
       }
     }
   }
 
-  void
-  RefreshRepository (const wxString & parentPath,
-                     const wxTreeItemId & parentId)
-  {
-    svn::Client client (GetContext ());
-    svn::Revision rev (svn::Revision::HEAD);
-    svn::Path parentPathUtf8 (PathUtf8 (parentPath));
-    svn::DirEntries entries =
-      client.ls (parentPathUtf8.c_str (), rev, false);
-    svn::DirEntries::const_iterator it;
-
-    bool parentHasSubdirectories = false;
-    for (it = entries.begin (); it != entries.end (); it++)
-    {
-      svn::DirEntry entry = *it;
-      int image = FOLDER_IMAGE_FOLDER;
-      int open_image = FOLDER_IMAGE_OPEN_FOLDER;
-      int offset = 1;
-
-      wxString fullPath = Utf8ToLocal (svn::Url::unescape (entry.name ()));
-      if (parentPath.Last () == '/')
-        offset = 0;
-      wxString filename (fullPath.Mid (parentPath.length () + offset));
-
-      if (entry.kind () != svn_node_dir)
-        continue;
-
-      parentHasSubdirectories = true;
-
-      FolderItemData * data =
-        new FolderItemData (FOLDER_TYPE_NORMAL,
-                            fullPath,
-                            filename, TRUE);
-
-      wxTreeItemId newId =
-        treeCtrl->AppendItem(parentId, filename,
-                             image, image, data);
-      treeCtrl->SetItemHasChildren (newId, true );
-      treeCtrl->SetItemImage (newId, open_image,
-                              wxTreeItemIcon_Expanded);
-    }
-
-    // Remove the "expansion" image from the folder if is has no children
-    if (!parentHasSubdirectories)
-      treeCtrl->SetItemHasChildren (parentId, FALSE);  }
 
   /**
    * Finds the child entry with @a path
@@ -691,7 +685,7 @@ public:
     bool success = false;
     wxTreeItemId id = bookmarkId;
 
-		do
+    do
     {
       const FolderItemData * data = GetItemData (id);
 
@@ -705,11 +699,11 @@ public:
         break;
 
       if (!data->isReal ())
-			  break;
+        break;
 
       const wxString nodePath (data->getPath ());
       if (nodePath.length () == 0)
-				break;
+        break;
 
       // check if @a path and @a nodePath match already
       // in this case we are done
@@ -916,6 +910,7 @@ BEGIN_EVENT_TABLE (FolderBrowser, wxControl)
   EVT_TREE_KEY_DOWN (-1, FolderBrowser::OnTreeKeyDown)
   EVT_SIZE (FolderBrowser::OnSize)
   EVT_CONTEXT_MENU (FolderBrowser::OnContextMenu)
+  EVT_TREE_BEGIN_DRAG (-1, FolderBrowser::OnBeginDrag)
 END_EVENT_TABLE ()
 
 FolderBrowser::FolderBrowser (wxWindow * parent, const wxWindowID id,
@@ -997,6 +992,12 @@ FolderBrowser::GetSelection () const
   return m->GetSelection ();
 }
 
+const FolderItemData *
+FolderBrowser::HitTest (const wxPoint & point) const
+{
+  return m->HitTest (point);
+}
+
 void
 FolderBrowser::OnSize (wxSizeEvent & WXUNUSED (event))
 {
@@ -1107,6 +1108,7 @@ FolderBrowser::ReadConfig (wxConfigBase * cfg)
 {
   wxASSERT (cfg);
 
+  Preferences prefs;
   long item, count;
   cfg->Read (ConfigBookmarkCount, &count, 0);
   for (item = 0; item < count; item++)
@@ -1118,8 +1120,9 @@ FolderBrowser::ReadConfig (wxConfigBase * cfg)
     keyFlatMode.Printf (ConfigFlatModeFmt, item);
     cfg->Read (keyPath, &path, wxEmptyString);
 
-    long flatMode;
-    cfg->Read (keyFlatMode, &flatMode, 0); 
+    long flatMode=0;
+    if (!prefs.resetFlatModeOnStart)
+      cfg->Read (keyFlatMode, &flatMode, 0); 
 
     if (path.Length () > 0)
       m->bookmarks [path] = Bookmark (flatMode != 0);
@@ -1175,6 +1178,46 @@ FolderBrowser::ExpandSelection ()
   m->treeCtrl->Expand (id);
 }
 
+void
+FolderBrowser::OnBeginDrag (wxTreeEvent & event)
+{
+  wxFileDataObject data;
+  const wxTreeItemId id = event.GetItem ();
+  if(!id.IsOk())
+  {
+    data.AddFile (GetPath ());
+  }
+  else
+  {
+    FolderItemData* itemData = m->GetItemData (id);
+    data.AddFile (itemData->getPath ());
+  }
+
+  wxDropSource dropSource (this);
+  dropSource.SetData (data);
+  /** 
+   * @todo we dont seem to need result
+   * wxDragResult result = dropSource.DoDragDrop (true);
+   */
+  dropSource.DoDragDrop (true);
+}
+
+const svn::StatusSel &
+FolderBrowser::GetStatusSel () const
+{
+  m->statusSel.clear ();
+
+  const FolderItemData * itemData = m->GetSelection ();
+
+  if (itemData != 0)
+  {
+    const svn::Status & status = itemData->getStatus ();
+    m->statusSel.push_back (status);
+  }
+
+  return m->statusSel;
+}
+
 /* -----------------------------------------------------------------
  * local variables:
  * eval: (load-file "../rapidsvn-dev.el")
