@@ -1,6 +1,6 @@
 /*
  * ====================================================================
- * Copyright (c) 2002-2006 The RapidSvn Group.  All rights reserved.
+ * Copyright (c) 2002-2008 The RapidSvn Group.  All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -37,6 +37,7 @@ namespace svn
 {
   class Context;
   class ContextListener;
+  class StatusSel;
 };
 
 class FolderBrowser : public wxControl
@@ -83,6 +84,21 @@ public:
   const FolderItemData * 
   GetSelection () const;
 
+  /** 
+   * the selected @ref Status instances
+   */
+  const svn::StatusSel &
+  GetStatusSel () const;
+
+  /**
+   * returns the "context" of the item at point.
+   * returns NULL if no item is at that location
+   *
+   * @return context of selection
+   */
+  const FolderItemData * 
+  HitTest (const wxPoint & point) const;
+
   /**
    * return the authentication context of the current selection
    *
@@ -217,6 +233,7 @@ private:
   void OnExpandItem (wxTreeEvent & event);
   void OnCollapseItem (wxTreeEvent & event);
   void OnContextMenu (wxContextMenuEvent & event);
+  void OnBeginDrag (wxTreeEvent & event);
 };
 
 #endif
