@@ -1,6 +1,6 @@
 /*
  * ====================================================================
- * Copyright (c) 2002-2006 The RapidSvn Group.  All rights reserved.
+ * Copyright (c) 2002-2008 The RapidSvn Group.  All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -36,7 +36,7 @@
 #include "utils.hpp"
 
 GetAction::GetAction (wxWindow * parent, const GetData & data)
-  : Action (parent, _("Update"), GetBaseFlags ()),
+  : Action (parent, _("Update")),
     m_data (data)
 {
 }
@@ -53,16 +53,24 @@ GetAction::Perform ()
   svn::Client client (GetContext ());
 
   wxString msg;
-  msg.Printf (wxT("Getting: %s, Revision %d"), m_data.path.c_str(), m_data.revision.revnum());
+  msg.Printf (wxT("Getting: %s, Revision %d"), m_data.path.c_str(), 
+              m_data.revision.revnum());
   Trace(msg);
 
   wxSetWorkingDirectory (Utf8ToLocal (GetPath ().c_str ()));
   client.update (svn::Path (LocalToUtf8 (m_data.path)),
                  m_data.revision,
-                 true);
+                 true, false);
 
   return true;
 }
+
+bool
+GetAction::CheckStatusSel (const svn::StatusSel & statusSel)
+{
+  return true;
+}
+
 /* -----------------------------------------------------------------
  * local variables:
  * eval: (load-file "../rapidsvn-dev.el")
