@@ -1,6 +1,6 @@
 /*
  * ====================================================================
- * Copyright (c) 2002-2006 The RapidSvn Group.  All rights reserved.
+ * Copyright (c) 2002-2008 The RapidSvn Group.  All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -33,19 +33,32 @@
 /**
  * History entry for commit log messages
  */
-extern const wxChar HISTORY_COMMIT_LOG[];
+extern const wxChar HISTORY_COMMIT_LOG [];
 
 
 /**
  * History entry for repository paths
  */
-extern const wxChar HISTORY_REPOSITORY[];
+extern const wxChar HISTORY_REPOSITORY [];
 
 
 /**
  * History entry for working directory paths
  */
-extern const wxChar HISTORY_WORKING_DIRECTORY[];
+extern const wxChar HISTORY_WORKING_DIRECTORY [];
+
+
+/**
+ * History entry for destinations of copy/move
+ * operations
+ */
+extern const wxChar HISTORY_COPYMOVE_DESTINATION [];
+
+
+/**
+ * History entry for Diff URLs
+ */
+extern const wxChar HISTORY_DIFF_URL [];
 
 
 #endif
