@@ -1,6 +1,6 @@
 /*
  * ====================================================================
- * Copyright (c) 2002-2006 The RapidSvn Group.  All rights reserved.
+ * Copyright (c) 2002-2008 The RapidSvn Group.  All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -41,9 +41,10 @@ IMPLEMENT_CLASS (HistoryValidator, wxValidator)
 
 HistoryValidator::HistoryValidator (const wxString & settingName,
                                     wxString * value,
-                                    bool dontUpdate)
+                                    bool dontUpdate,
+                                    bool useMostRecent)
  :  wxValidator (), m_settingName (settingName), m_value (value),
-    m_dontUpdate (dontUpdate)
+    m_dontUpdate (dontUpdate), m_useMostRecent (useMostRecent)
 {
 }
 
@@ -62,6 +63,7 @@ HistoryValidator::Copy(const HistoryValidator & val)
   m_settingName = val.m_settingName;
   m_value = val.m_value;
   m_dontUpdate = val.m_dontUpdate;
+  m_useMostRecent = val.m_useMostRecent;
 
   return true;
 }
@@ -104,15 +106,20 @@ HistoryValidator::TransferToWindow()
       comboBox->Append (value);
     }
 
-    if (m_value != 0)
+    if (!m_useMostRecent)
+      comboBox->SetValue (wxEmptyString);
+    else
     {
-      if (comboBox->FindString (*m_value) != wxNOT_FOUND)
-        comboBox->SetValue (*m_value);
-    }
+      if (m_value != 0)
+      {
+        if (comboBox->FindString (*m_value) != wxNOT_FOUND)
+          comboBox->SetValue (*m_value);
+      }
 
-    // if we have an entry, select it
-    if (count > 0)
-      comboBox->SetSelection (0, 0);
+      // if we have an entry, select it
+      if ((count > 0))
+        comboBox->SetSelection (0, 0);
+    }
 
     return true;
   }
@@ -120,7 +127,7 @@ HistoryValidator::TransferToWindow()
   {
     wxTextCtrl * textCtrl = (wxTextCtrl *)m_validatorWindow;
 
-    if (list.Count () == 0)
+    if ((list.Count () == 0) || !m_useMostRecent)
       textCtrl->SetValue (wxT(""));
     else
     {
@@ -151,7 +158,7 @@ HistoryValidator::TransferFromWindow()
     wxComboBox * comboBox = (wxComboBox *)m_validatorWindow;
 
     wxString lastValue (comboBox->GetValue ());
-    TrimString (lastValue);
+    lastValue.Trim ();
 
     if (!m_dontUpdate && (lastValue.Length () > 0))
       TheHistoryManager.AddEntryToList (m_settingName, lastValue);
@@ -166,7 +173,7 @@ HistoryValidator::TransferFromWindow()
     wxTextCtrl * textCtrl = (wxTextCtrl *)m_validatorWindow;
 
     wxString lastValue (textCtrl->GetValue ());
-    TrimString (lastValue);
+    lastValue.Trim ();
 
     if (!m_dontUpdate && (lastValue.Length () > 0))
       TheHistoryManager.AddEntryToList (m_settingName, lastValue);
