@@ -1,6 +1,6 @@
 /*
  * ====================================================================
- * Copyright (c) 2002-2006 The RapidSvn Group.  All rights reserved.
+ * Copyright (c) 2002-2008 The RapidSvn Group.  All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -40,6 +40,7 @@ enum
   ID_RefreshWithUpdate,
   ID_ShowUnversioned,
   ID_IgnoreExternals,
+  ID_ShowIgnored,
   ID_HelpContents,
   ID_HelpIndex,
   ID_HelpStartupTips,
@@ -81,6 +82,7 @@ enum
   ID_Move,
   ID_Property,
   ID_Rename,
+  ID_UserResolve,
   ID_Resolve,
   ID_Revert,
   ID_Switch,
@@ -88,6 +90,7 @@ enum
   ID_Unlock,
   ID_Edit,
   ID_Annotate,
+  ID_Ignore,
   ID_File_Max,
 
   // Reserve space for 16 file verbs (I've never seen any files with more)
@@ -164,6 +167,7 @@ enum
   TOKEN_ACTION_END,
   TOKEN_CMD,
   TOKEN_CMD_DIFF,
+  TOKEN_CMD_MERGE,
   TOKEN_CMD_VIEW,
   TOKEN_DIFF,
   TOKEN_GET,
@@ -175,6 +179,7 @@ enum
   TOKEN_UPDATE_ASCENDING,
   TOKEN_ANNOTATE,
   TOKEN_LOG,
+  TOKEN_DRAG_N_DROP,
 
   LISTENER_MIN,
   SIG_GET_LOG_MSG,
