@@ -1,6 +1,6 @@
 /*
  * ====================================================================
- * Copyright (c) 2002-2006 The RapidSvn Group.  All rights reserved.
+ * Copyright (c) 2002-2008 The RapidSvn Group.  All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -171,7 +171,7 @@ ImportDlg::OnOk (wxCommandEvent &event)
 
   TrimString (m->data.Repository);
   TrimString (m->data.Path);
-  TrimString (m->data.LogMessage);
+  m->data.LogMessage.Trim ();
 
   if (m->data.Repository.IsEmpty ())
   {
@@ -196,7 +196,7 @@ ImportDlg::OnOk (wxCommandEvent &event)
     }
   }
 
-  wxDialog::OnOK(event);
+  wxDialog::EndModal (wxID_OK);
 }
 
 void
