@@ -1,6 +1,6 @@
 /*
  * ====================================================================
- * Copyright (c) 2002-2006 The RapidSvn Group.  All rights reserved.
+ * Copyright (c) 2002-2008 The RapidSvn Group.  All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -253,7 +253,7 @@ public:
   void 
   handleEvent (wxCommandEvent & event)
   {
-    switch (event.m_id)
+    switch (event.GetId ())
     {
     case SIG_GET_LOG_MSG:
       callbackGetLogMessage ();
@@ -378,11 +378,7 @@ Listener::contextNotify (const char *path,
     _("Failed to unlock")  // svn_wc_notify_failed_unlock
   };
 
-#if CHECK_SVN_SUPPORTS_LOCK
   static const int MAX_ACTION = svn_wc_notify_failed_unlock;
-#else
-  static const int MAX_ACTION = svn_wc_notify_commit_postfix_txdelta;
-#endif
 
   if (ACTION_NAMES[action] != NULL && action >= 0 && action <= MAX_ACTION)
   {
