@@ -1,6 +1,6 @@
 /*
  * ====================================================================
- * Copyright (c) 2002-2006 The RapidSvn Group.  All rights reserved.
+ * Copyright (c) 2002-2008 The RapidSvn Group.  All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,6 +30,7 @@
 // svncpp
 #include "svncpp/client.hpp"
 #include "svncpp/revision.hpp"
+#include "svncpp/status_selection.hpp"
 
 // app
 #include "action_event.hpp"
@@ -38,7 +39,7 @@
 #include "log_data.hpp"
 
 LogAction::LogAction (wxWindow * parent)
-  : Action (parent, _("Log"), GetBaseFlags ())
+  : Action (parent, _("Log"), DONT_UPDATE)
 {
 }
 
@@ -58,6 +59,18 @@ LogAction::Perform ()
   return true;
 }
 
+bool
+LogAction::CheckStatusSel (const svn::StatusSel & statusSel)
+{
+  if (1 != statusSel.size ())
+    return false;
+
+  if (statusSel.hasUnversioned ())
+    return false;
+
+  return true;
+}
+
 /* -----------------------------------------------------------------
  * local variables:
  * eval: (load-file "../rapidsvn-dev.el")
