@@ -1,6 +1,6 @@
 /*
  * ====================================================================
- * Copyright (c) 2002-2006 The RapidSvn Group.  All rights reserved.
+ * Copyright (c) 2002-2008 The RapidSvn Group.  All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -32,6 +32,7 @@
 #include "wx/valgen.h"
 #include "wx/listctrl.h"
 #include "wx/splitter.h"
+#include "wx/notebook.h"
 
 
 // svncpp
@@ -394,20 +395,11 @@ public:
     const svn::LogEntry & entry = (*entries)[index];
 
     wxString message (Utf8ToLocal (entry.message.c_str ()));
-    message.Trim (false);
+    message.Trim ();
 
-    // TODO we have to doublecheck this with wxMSW and wxGTK
-    //int selection = m_notebook->GetSelection ();
-
-    //m_logMsg->Show (false);
     m_logMsg->SetValue (message);
-    //m_logMsg->Show (true);
 
-    //m_affectedList->Show (false);
     m_affectedList->SetValue (entry.changedPaths);
-    //m_affectedList->Show (true);
-
-    //m_notebook->SetSelection (selection);
 
     CheckButtons ();
   }
@@ -497,20 +489,20 @@ public:
   void 
   CheckButtons ()
   {
+    svn::Path pathUtf8 (PathUtf8 (path));
+    bool isUrl = pathUtf8.isUrl ();
     int count = m_logList->GetSelectedItemCount ();
 
-    m_buttonGet  ->Enable (count == 1);
+    m_buttonGet  ->Enable ((count == 1) && (!isUrl));
     m_buttonView ->Enable (count == 1);
-    // If the bookmark is a working copy, then we can compare a revision against the local copy
-    svn::Path bookmarkFilePath (PathUtf8 (path));
-    if (bookmarkFilePath.isUrl())
-    {
+
+    // If the bookmark is a working copy, then we can 
+    // compare a revision against the local copy
+    if (isUrl)
       m_buttonDiff ->Enable ((count == 2));
-    }
     else
-    {
       m_buttonDiff ->Enable ((count == 1) || (count == 2));
-    }
+
     m_buttonMerge->Enable (count == 2);
     m_buttonAnnotate->Enable (count == 1);
   }
