@@ -1,6 +1,6 @@
 /*
  * ====================================================================
- * Copyright (c) 2002-2006 The RapidSvn Group.  All rights reserved.
+ * Copyright (c) 2002-2008 The RapidSvn Group.  All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -36,13 +36,13 @@
 #include "utils.hpp"
 
 MergeAction::MergeAction (wxWindow * parent)
-  : Action (parent, _("Merge"), GetBaseFlags ())
+  : Action (parent, _("Merge"))
 {
   m_data.calledByLogDlg = false;
 }
 
 MergeAction::MergeAction (wxWindow * parent, MergeData & data)
-  : Action (parent, _("Merge"), GetBaseFlags ()), m_data (data)
+  : Action (parent, _("Merge")), m_data (data)
 {
   m_data.calledByLogDlg = true;
 }
@@ -113,6 +113,12 @@ MergeAction::Perform ()
   return true;
 }
 
+bool
+MergeAction::CheckStatusSel (const svn::StatusSel & statusSel)
+{
+  return true;
+}
+
 /* -----------------------------------------------------------------
  * local variables:
  * eval: (load-file "../rapidsvn-dev.el")
