@@ -1,6 +1,6 @@
 /*
  * ====================================================================
- * Copyright (c) 2002-2006 The RapidSvn Group.  All rights reserved.
+ * Copyright (c) 2002-2008 The RapidSvn Group.  All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -35,7 +35,7 @@
 #include "utils.hpp"
 
 MkdirAction::MkdirAction (wxWindow * parent, const wxString & path)
- : Action (parent, _("Mkdir"), GetBaseFlags ()),
+ : Action (parent, _("Mkdir"), UPDATE_TREE),
    m_path (path)
 {
 }
@@ -66,10 +66,6 @@ MkdirAction::Perform ()
 {
   svn::Client client (GetContext ());
 
-  // add target to path
-  wxString newDir (m_path + m_target);
-  // TODO: What is newDir for???
-
   svn::Path pathUtf8 (PathUtf8 (m_path));
   svn::Path targetUtf8 (PathUtf8 (m_target));
   pathUtf8.addComponent (targetUtf8.c_str ());
@@ -77,6 +73,13 @@ MkdirAction::Perform ()
   client.mkdir (pathUtf8);
   return true;
 }
+
+bool
+MkdirAction::CheckStatusSel (const svn::StatusSel & statusSel)
+{
+  return true;
+}
+
 /* -----------------------------------------------------------------
  * local variables:
  * eval: (load-file "../rapidsvn-dev.el")
