@@ -1,6 +1,6 @@
 /*
  * ====================================================================
- * Copyright (c) 2002-2006 The RapidSvn Group.  All rights reserved.
+ * Copyright (c) 2002-2008 The RapidSvn Group.  All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,12 +30,13 @@
 #include "svncpp/client.hpp"
 
 // app
-#include "move_action.hpp"
 #include "destination_dlg.hpp"
+#include "hist_entries.hpp"
+#include "move_action.hpp"
 #include "utils.hpp"
 
 MoveAction::MoveAction (wxWindow * parent, int kind)
- : Action (parent, wxEmptyString, GetBaseFlags ()),
+ : Action (parent, wxEmptyString, UPDATE_TREE),
    m_kind (kind)
 {
   if (kind == MOVE_MOVE)
@@ -60,7 +61,9 @@ MoveAction::Prepare ()
 
   // create description for the dialog
   DestinationDlg dlg (GetParent (), GetName (),
-                      _("Select destination:"), flags);
+                      _("Select destination:"), flags,
+                      wxEmptyString,
+                      HISTORY_COPYMOVE_DESTINATION);
 
   if (dlg.ShowModal () != wxID_OK)
     return false;
@@ -96,6 +99,12 @@ MoveAction::Perform ()
   return true;
 }
 
+bool
+MoveAction::CheckStatusSel (const svn::StatusSel & statusSel)
+{
+  return true;
+}
+
 /* -----------------------------------------------------------------
  * local variables:
  * eval: (load-file "../rapidsvn-dev.el")
