@@ -1,6 +1,6 @@
 /*
  * ====================================================================
- * Copyright (c) 2002-2006 The RapidSvn Group.  All rights reserved.
+ * Copyright (c) 2002-2008 The RapidSvn Group.  All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -85,6 +85,16 @@ public:
    */
   wxString diffToolArgs;
 
+  /**
+   * location of the merge-tool executable
+   */
+  wxString mergeTool;
+
+  /**
+   * arguments to pass to the merge tool
+   */
+  wxString mergeToolArgs;
+
   /**
    * delete all temporary files made by the program upon exit
    */
@@ -101,6 +111,16 @@ public:
    */
   bool useAuthCache;
 
+  /**
+   * Default commit comment to last comment used
+   */
+  bool useLastCommitMessage;
+
+   /**
+   * always save state of flat mode as reset/false
+   */
+  bool resetFlatModeOnStart;
+
 private:
   void Read ();
   void Write () const;
