@@ -1,6 +1,6 @@
 /*
  * ====================================================================
- * Copyright (c) 2002-2006 The RapidSvn Group.  All rights reserved.
+ * Copyright (c) 2002-2008 The RapidSvn Group.  All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -31,6 +31,9 @@
 #include <wx/cshelp.h>
 #include <wx/image.h>
 
+// svncpp
+#include "svncpp/wc.hpp"
+
 //app
 #include "config.hpp"
 #include "hist_mgr.hpp"
@@ -65,6 +68,10 @@ bool RapidSvnApp::OnInit ()
   // Add support for PNG
   wxImage::AddHandler(new wxPNGHandler);
 
+  // Add support for SVN_ASP_DOT_NET_HACK
+  if (wxGetEnv (wxT("SVN_ASP_DOT_NET_HACK"), 0))
+    svn::Wc::setAdmDir ("_svn");
+
 #ifdef  USE_HTML_HELP
   // Initialise the HTML help
   wxFileSystem::AddHandler (new wxZipFSHandler);
