@@ -1,6 +1,6 @@
 /*
  * ====================================================================
- * Copyright (c) 2002-2006 The RapidSvn Group.  All rights reserved.
+ * Copyright (c) 2002-2008 The RapidSvn Group.  All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -102,6 +102,7 @@ private:
   void OnRefreshWithUpdate (wxCommandEvent & event);
   void OnShowUnversioned (wxCommandEvent & event);
   void OnIgnoreExternals (wxCommandEvent & event);
+  void OnShowIgnored (wxCommandEvent & event);
   void OnStop (wxCommandEvent & event);
 
   // Query menu
@@ -173,19 +174,8 @@ private:
   void OnSize (wxSizeEvent & sizeEvent);
 
   // Enable/disable action menu items
-  bool ValidateIDActionFlags (int id, unsigned int selectionActionFlags);
   void OnUpdateCommand (wxUpdateUIEvent & updateUIEvent);
 
-  const svn::Targets
-  GetActionTargets() const;
-
-  /**
-   * determine the properties of what has been selected
-   * in terms of the relevant Action Flags.
-   */
-  unsigned int
-  GetSelectionActionFlags () const;
-
   // Utility functions
   void ShowLog ();
   void ShowInfo ();
@@ -216,7 +206,6 @@ private:
 
   wxString m_title;
   svn::Context * m_context;
-  ActivePane m_activePane;
 
 private:
   DECLARE_EVENT_TABLE ()
