@@ -1,6 +1,6 @@
 /*
  * ====================================================================
- * Copyright (c) 2002-2006 The RapidSvn Group.  All rights reserved.
+ * Copyright (c) 2002-2008 The RapidSvn Group.  All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -32,7 +32,7 @@
 #include "revert_action.hpp"
 
 RevertAction::RevertAction (wxWindow * parent)
-  : Action (parent, _("Revert"), GetBaseFlags ())
+  : Action (parent, _("Revert"))
 {
 }
 
@@ -61,6 +61,12 @@ RevertAction::Perform ()
   return true;
 }
 
+bool
+RevertAction::CheckStatusSel (const svn::StatusSel & statusSel)
+{
+  return true;
+}
+
 /* -----------------------------------------------------------------
  * local variables:
  * eval: (load-file "../rapidsvn-dev.el")
