@@ -1,6 +1,6 @@
 /*
  * ====================================================================
- * Copyright (c) 2002-2006 The RapidSvn Group.  All rights reserved.
+ * Copyright (c) 2002-2008 The RapidSvn Group.  All rights reserved.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -38,12 +38,11 @@
 #include "svncpp/client.hpp"
 #include "svncpp/dirent.hpp"
 #include "svncpp/exception.hpp"
+#include "svncpp/info.hpp"
 #include "svncpp/pool.hpp"
 #include "svncpp/status.hpp"
 #include "svncpp/targets.hpp"
 #include "svncpp/url.hpp"
-#include "m_svn_status.hpp"
-#include "m_converter.hpp"
 
 namespace svn
 {
@@ -69,7 +68,7 @@ namespace svn
       {
         char *path;
         void *val;
-        apr_hash_this (hi, (const void **) &path, NULL, &val);
+        apr_hash_this (hi, (const void **)&path, NULL, &val);
 
         svn_log_changed_path_t *log_item = reinterpret_cast<svn_log_changed_path_t *> (val);
         
@@ -84,14 +83,14 @@ namespace svn
     return NULL;
   }
 
-  static void StatusEntriesFunc (void *baton,
-                                 const char *path,
-                                 svn::SvnStatus *status)
+  static void 
+  statusEntriesFunc (void *baton,
+                     const char *path,
+                     svn_wc_status2_t *status)
   {
     StatusEntries * entries = static_cast<StatusEntries *>(baton);
 
-    static Converter converter;
-    entries->push_back (converter.toStatus (path, status));
+    entries->push_back (Status (path, status));
   }
 
   static StatusEntries
@@ -109,12 +108,11 @@ namespace svn
     Revision rev (Revision::HEAD);
     Pool pool;
 
-#if (CHECK_SVN_VERSION(1,2))
     error = svn_client_status2 (
       &revnum,    // revnum
       path,       // path
       rev,        // revision
-      StatusEntriesFunc, // status func
+      statusEntriesFunc, // status func
       &entries,   // status baton
       descend,    // recurse
       get_all,
@@ -123,20 +121,6 @@ namespace svn
       ignore_externals, // ignore_externals
       *context,   // client ctx
       pool);
-#else
-    error = svn_client_status (
-      &revnum,    // revnum
-      path,       // path
-      rev,        // revision
-      StatusEntriesFunc, // status func
-      &entries,   // status baton
-      descend,    // recurse
-      get_all,
-      update,
-      no_ignore,
-      *context,   //client ctx
-      pool);
-#endif
 
     if (error!=NULL)
       throw ClientException (error);
@@ -168,9 +152,9 @@ namespace svn
     e->cmt_date = dirEntry.time ();
     e->cmt_author = dirEntry.lastAuthor ();
 
-    svn::SvnStatus * s =
-      static_cast<svn::SvnStatus *> (
-        apr_pcalloc (pool, sizeof (svn::SvnStatus)));
+    svn_wc_status2_t * s =
+      static_cast<svn_wc_status2_t *> (
+        apr_pcalloc (pool, sizeof (svn_wc_status2_t)));
     s->entry = e;
     s->text_status = svn_wc_status_normal;
     s->prop_status = svn_wc_status_normal;
@@ -179,8 +163,7 @@ namespace svn
     s->repos_text_status = svn_wc_status_normal;
     s->repos_prop_status = svn_wc_status_normal;
 
-    static Converter converter;
-    return converter.toStatus (url.c_str (), s);
+    return Status (url.c_str (), s);
   }
 
   static StatusEntries
@@ -224,28 +207,6 @@ namespace svn
                           no_ignore, m_context, ignore_externals);
   }
 
-  Status 
-  Client::singleStatus (const char * path) throw (ClientException)
-  {
-    Revision rev (Revision::HEAD);
-    StatusEntries entries = status (path, false);
-
-    // now seach the returned list of entries for @a path
-    StatusEntries::const_iterator it=entries.begin ();
-
-    for(; it!=entries.end (); it++)
-    {
-      Status status=*it;
-
-      if (strcmp (status.path (), path) == 0)
-        return status;
-    }
-
-    // if we come to this point we havent found a thing
-    return Status ();
-  }
-
-#if CHECK_SVN_SUPPORTS_PEG
   const LogEntries *
   Client::log (const char * path, const Revision & revisionStart, 
                const Revision & revisionEnd, bool discoverChangedPaths,
@@ -277,59 +238,51 @@ namespace svn
 
     return entries;
   }
-#else
-  const LogEntries *
-  Client::log (const char * path, const Revision & revisionStart, 
-               const Revision & revisionEnd, bool discoverChangedPaths,
-               bool strictNodeHistory ) throw (ClientException)
+
+
+  /** 
+   * callback function for Client::info, will be
+   * called for every entry svn_client_info wants to
+   * return
+   */
+  static svn_error_t *
+  infoReceiverFunc (void * baton, const char * path,
+                    const svn_info_t * info,
+                    apr_pool_t * pool)
   {
-    Pool pool;
-    Targets target (path);
-    LogEntries * entries = new LogEntries ();
-    svn_error_t *error;
+    InfoVector * infoVector = static_cast<InfoVector *>(baton);
 
-    error = svn_client_log (
-      target.array (pool), 
-      revisionStart.revision (), 
-      revisionEnd.revision (), 
-      discoverChangedPaths ? 1 : 0,
-      strictNodeHistory ? 1 : 0,
-      logReceiver,
-      entries, 
-      *m_context, // client ctx
-      pool);
+    infoVector->push_back (Info (path, info));
 
-    if (error != NULL)
-    {
-      delete entries;
-      throw ClientException (error);
-    }
-
-    return entries;
+    return 0;
   }
-#endif
 
-  Entry
-  Client::info (const char * path)
+
+  InfoVector
+  Client::info (const Path & pathOrUrl,
+                bool recurse,
+                const Revision & revision,
+                const Revision & pegRevision) throw (ClientException)
   {
     Pool pool;
-    svn_wc_adm_access_t * adm_access;
-
+    InfoVector infoVector;
+    
     svn_error_t * error =
-      svn_wc_adm_probe_open (&adm_access, NULL, path, FALSE,
-                             FALSE, pool);
-    if (error != NULL)
+      svn_client_info (pathOrUrl.c_str (),
+                       pegRevision.revision (),
+                       revision.revision (),
+                       infoReceiverFunc,
+                       &infoVector,
+                       recurse,
+                       *m_context,
+                       pool);
+
+    if (error != 0)
       throw ClientException (error);
 
-    const svn_wc_entry_t * entry;
-    error = svn_wc_entry (&entry, path, adm_access, FALSE, pool);
-
-    if (error != NULL)
-      throw ClientException (error);
-
-    // entry may be NULL
-    return Entry( entry );
+    return infoVector;
   }
+
 }
 
 /* -----------------------------------------------------------------
