@@ -1,6 +1,6 @@
 /*
  * ====================================================================
- * Copyright (c) 2002-2006 The RapidSvn Group.  All rights reserved.
+ * Copyright (c) 2002-2008 The RapidSvn Group.  All rights reserved.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -151,6 +151,10 @@ namespace svn
     if (0 == component)
       return;
 
+    // in case of an empty string, return
+    if (*component == 0)
+      return;
+
     // if the @a component is absolute, simply
     // use it
     if (isAbsolute (component))
