@@ -1,6 +1,6 @@
 /*
  * ====================================================================
- * Copyright (c) 2002-2006 The RapidSvn Group.  All rights reserved.
+ * Copyright (c) 2002-2008 The RapidSvn Group.  All rights reserved.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -125,6 +125,24 @@ namespace svn
       return "";
     }
   }
+
+  void
+  Targets::push_back (const Path & path)
+  {
+    m_targets.push_back (path);
+  }
+
+  void
+  Targets::clear ()
+  {
+    m_targets.clear ();
+  }
+
+  void
+  Targets::reserve (size_t size)
+  {
+    m_targets.reserve (size);
+  }
 }
 
 /* -----------------------------------------------------------------
