@@ -1,6 +1,6 @@
 /*
  * ====================================================================
- * Copyright (c) 2002-2006 The RapidSvn Group.  All rights reserved.
+ * Copyright (c) 2002-2008 The RapidSvn Group.  All rights reserved.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -35,17 +35,21 @@
 
 namespace svn
 {
-  const char * Wc::ADM_DIR_NAME = SVN_WC_ADM_DIR_NAME;
-
   bool 
   Wc::checkWc (const char * dir)
   {
-    Pool pool;
     Path path (dir);
+    return Wc::checkWc (path);
+  }
+
+  bool
+  Wc::checkWc (const Path & dir)
+  {
+    Pool pool;
     int wc;
 
     svn_error_t * error =
-      svn_wc_check_wc (path.c_str (), &wc, pool);
+      svn_wc_check_wc (dir.c_str (), &wc, pool);
 
     if ((error != NULL) || (wc == 0))
     {
@@ -73,6 +77,27 @@ namespace svn
     if(error != NULL)
       throw ClientException (error);
   }
+
+  void
+  Wc::setAdmDir (const char * dir)
+  {
+    Pool pool;
+
+    svn_error_t * error = 
+      svn_wc_set_adm_dir (dir, pool);
+
+    if(error != NULL)
+      throw ClientException (error);
+  }
+
+  bool
+  Wc::isAdmDir (const char * name)
+  {
+    Pool pool;
+
+    return 0 != svn_wc_is_adm_dir (name, pool);
+  }
+
 }
 
 /* -----------------------------------------------------------------
