@@ -1,6 +1,6 @@
 /*
  * ====================================================================
- * Copyright (c) 2002-2006 The RapidSvn Group.  All rights reserved.
+ * Copyright (c) 2002-2008 The RapidSvn Group.  All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -28,19 +28,38 @@
 
 // svncpp
 #include "svncpp/client.hpp"
+#include "svncpp/info.hpp"
 #include "svncpp/status.hpp"
 #include "svncpp/url.hpp"
 
 // app
 #include "switch_action.hpp"
-#include "update_dlg.hpp"
+#include "switch_dlg.hpp"
 #include "utils.hpp"
 
-SwitchAction::SwitchAction (wxWindow * parent)
- : Action (parent, _("Switch URL"), GetBaseFlags ())
+struct SwitchAction::Data
 {
+public:
+  wxString old_url;
+  wxString new_url;
+  svn::Revision revision;
+  bool recursive;
+  bool relocate;
+};
+
+SwitchAction::SwitchAction (wxWindow * parent)
+ : Action (parent, _("Switch URL"))
+{
+  m = new Data ();
 }
 
+
+SwitchAction::~SwitchAction ()
+{
+  delete m;
+}
+
+
 bool
 SwitchAction::Prepare ()
 {
@@ -50,28 +69,25 @@ SwitchAction::Prepare ()
   }
 
   // first try to get the URL for the target
-  wxString url;
-  {
-    svn::Path path = GetTarget ();
-    svn::Client client (GetContext ());
-    svn::Entry entry (client.info (path.c_str ()));
-    const char* urlCharBuffer = entry.url ();
-    url = Utf8ToLocal (svn::Url::unescape (urlCharBuffer));
-  }
+  svn::Path path = GetTarget ();
+  svn::Client client (GetContext ());
+  svn::InfoVector infoVector (client.info (path));
+  if (infoVector.size () != 1)
+    return false;
 
-  // create flags for the dialog
-  int flags = UpdateDlg::WITH_URL;
+  m->old_url = Utf8ToLocal (svn::Url::unescape (infoVector[0].url ()));
 
-  UpdateDlg dlg (GetParent (), _("Switch URL"), flags,
-                 true);
-  dlg.GetData ().url = url;
+  SwitchDlg dlg (GetParent (), m->old_url, true, false);
 
   if (dlg.ShowModal () != wxID_OK)
   {
     return false;
   }
 
-  m_data = dlg.GetData ();
+  m->new_url = dlg.GetUrl ();
+  m->revision = dlg.GetRevision ();
+  m->recursive = dlg.GetRecursive ();
+  m->relocate = dlg.GetRelocate ();
 
   return true;
 }
@@ -80,23 +96,28 @@ bool
 SwitchAction::Perform ()
 {
   svn::Path path = GetTarget ();
-  svn::Path urlUtf8 (PathUtf8 (m_data.url));
-  svn::Revision revision (svn::Revision::HEAD);
-
-  if (!m_data.useLatest)
-  {
-    svn_revnum_t revnum;
-    TrimString (m_data.revision);
-    m_data.revision.ToLong (&revnum);
-    revision = revnum;
-  }
-
   svn::Client client (GetContext ());
-  client.doSwitch (path, urlUtf8.c_str (), revision,
-                   m_data.recursive);
 
+  if (m->relocate)
+    client.relocate (path, 
+                     LocalToUtf8 (m->old_url).c_str (),
+                     LocalToUtf8 (m->new_url).c_str (),
+                     m->recursive);
+  else
+    client.doSwitch (path,  
+                     LocalToUtf8 (m->new_url).c_str (), 
+                     m->revision,
+                     m->recursive);
+  
   return true;
 }
+
+bool
+SwitchAction::CheckStatusSel (const svn::StatusSel & statusSel)
+{
+  return true;
+}
+
 /* -----------------------------------------------------------------
  * local variables:
  * eval: (load-file "../rapidsvn-dev.el")
