@@ -1,6 +1,6 @@
 /*
  * ====================================================================
- * Copyright (c) 2002-2006 The RapidSvn Group.  All rights reserved.
+ * Copyright (c) 2002-2008 The RapidSvn Group.  All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,7 +30,12 @@
 
 // app
 #include "action.hpp"
-#include "update_data.hpp"
+
+// forward declarations
+namespace svn
+{
+  class StatusSel;
+}
 
 /**
  * this action class can be used to copy, move and rename
@@ -46,19 +51,20 @@ public:
    */
   SwitchAction (wxWindow * parent);
 
-  virtual bool Perform ();
-  virtual bool Prepare ();
-  
-  /**
-   * Describe which targets the action can perform upon
-   */
-  static unsigned int GetBaseFlags ()
-  {
-    return SINGLE_TARGET|VERSIONED_WC_TYPE;
-  }
+  virtual ~SwitchAction ();
+
+  virtual bool 
+  Perform ();
+
+  virtual bool 
+  Prepare ();
+
+  static bool
+  CheckStatusSel (const svn::StatusSel & statusSel);
 
 private:
-  UpdateData m_data;
+  struct Data;
+  Data * m;
 };
 
 #endif
