@@ -1,6 +1,6 @@
 /*
  * ====================================================================
- * Copyright (c) 2002-2006 The RapidSvn Group.  All rights reserved.
+ * Copyright (c) 2002-2008 The RapidSvn Group.  All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -29,7 +29,7 @@
 // svncpp
 #include "svncpp/client.hpp"
 #include "svncpp/path.hpp"
-#include "svncpp/targets.hpp"
+#include "svncpp/status_selection.hpp"
 
 // app
 #include "update_action.hpp"
@@ -37,7 +37,7 @@
 #include "utils.hpp"
 
 UpdateAction::UpdateAction (wxWindow * parent)
-  : Action (parent, _("Update"), GetBaseFlags ())
+  : Action (parent, _("Update"))
 {
 }
 
@@ -79,11 +79,30 @@ UpdateAction::Perform ()
   wxSetWorkingDirectory (Utf8ToLocal (GetPath ().c_str ()));
   svn::Client client (GetContext ());
 
-  client.update2 (GetTargets (), revision, m_data.recursive, 
-                  m_data.ignoreExternals);
+  client.update (GetTargets (), revision, m_data.recursive, 
+                 m_data.ignoreExternals);
 
   return true;
 }
+
+bool
+UpdateAction::CheckStatusSel (const svn::StatusSel & statusSel)
+{
+  // no Update for repositories
+  if (statusSel.hasUrl ())
+    return false;
+
+  // we NEED statusSel
+  if (0 == statusSel.size ())
+    return false;
+
+  // No unversioned files allowed
+  if (statusSel.hasUnversioned ())
+    return false;
+
+  return true;
+}
+
 /* -----------------------------------------------------------------
  * local variables:
  * eval: (load-file "../rapidsvn-dev.el")
