@@ -1,6 +1,6 @@
 /*
  * ====================================================================
- * Copyright (c) 2002-2006 The RapidSvn Group.  All rights reserved.
+ * Copyright (c) 2002-2008 The RapidSvn Group.  All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -37,7 +37,6 @@
 #include "apr_time.h"
 
 // svncpp
-#include "svncpp/check.hpp"
 #include "svncpp/client.hpp"
 #include "svncpp/status.hpp"
 #include "svncpp/path.hpp"
@@ -169,16 +168,18 @@ AppendModifyMenu (wxMenu * parentMenu)
 
   parentMenu->AppendSeparator ();
 
-  AppendMenuItem (parentMenu, ID_Add, _("&Add\tCTRL-A"),
+  AppendMenuItem (parentMenu, ID_Add, _("&Add\tINS"),
                   EMBEDDED_BITMAP(add_png));
   AppendMenuItem (parentMenu, ID_AddRecursive, _("Add r&ecursive"));
   AppendMenuItem (parentMenu, ID_Delete, _("&Delete\tDEL"),
                   EMBEDDED_BITMAP(delete_png));
+  AppendMenuItem (parentMenu, ID_Ignore, _("&Ignore\tCTRL-DEL"));
 
   parentMenu->AppendSeparator ();
 
   AppendMenuItem (parentMenu, ID_Revert, _("Re&vert\tCTRL-V"),
                   EMBEDDED_BITMAP(revert_png));
+  AppendMenuItem (parentMenu, ID_UserResolve, _("In&teractive Resolve...\tCTRL-T"));					
   AppendMenuItem (parentMenu, ID_Resolve, _("Re&solve conflicts\tCTRL-S"),
                   EMBEDDED_BITMAP(resolve_png));
 
@@ -192,13 +193,10 @@ AppendModifyMenu (wxMenu * parentMenu)
                   EMBEDDED_BITMAP(rename_png));
   AppendMenuItem (parentMenu, ID_Mkdir, _("Make &directory...\tF7"));
 
-  if (svn::SUPPORTS_LOCK)
-  {
-    parentMenu->AppendSeparator ();
+  parentMenu->AppendSeparator ();
 
-    AppendMenuItem (parentMenu, ID_Lock, _("&Lock..."));
-    AppendMenuItem (parentMenu, ID_Unlock, _("&Unlock"));
-  }
+  AppendMenuItem (parentMenu, ID_Lock, _("&Lock..."));
+  AppendMenuItem (parentMenu, ID_Unlock, _("&Unlock"));
 }
 
 void
@@ -261,7 +259,7 @@ AppendMenuItem (wxMenu & menu, int id)
     break;
 
   case ID_RemoveBookmark:
-    caption = _("&Remove Bookmark...");
+    caption = _("&Remove Bookmark");
     // bitmap = EMBEDDED_BITMAP(remove_bookmark_png);
     break;
 
@@ -287,7 +285,7 @@ AppendMenuItem (wxMenu & menu, int id)
     break;
 
   case ID_Commit:
-    caption = _("Co&mmit...\tCTRL-M");
+    caption = _("Co&mmit...\tCTRL-ENTER");
     bitmap = EMBEDDED_BITMAP(commit_png);
     break;
 
@@ -392,7 +390,7 @@ StatusDescription (const svn_wc_status_kind kind)
     break;
   case svn_wc_status_unversioned:
     return _("unversioned");
-	break;
+  break;
   case svn_wc_status_normal:
     return _("normal");
     break;
@@ -426,6 +424,8 @@ StatusDescription (const svn_wc_status_kind kind)
   case svn_wc_status_incomplete:
     return _("incomplete");
     break;
+  case svn_wc_status_ignored:
+    return _("ignored");
   default:
     return _("unknown value");
     break;
@@ -475,18 +475,6 @@ Utf8ToLocal (const char* srcUtf8)
   return dst;
 }
 
-wxFileName
-Utf8ToFileName (const char * srcUtf8)
-{
-#if wxUSE_UNICODE
-  wxString dst (srcUtf8, wxConvUTF8);
-#else
-  wxString dst (wxConvUTF8.cMB2WC(srcUtf8), *GetWXLocalConv ());
-#endif
-
-  return dst;
-}
-
 wxString
 Utf8ToLocal (const std::string& srcUtf8)
 {
