@@ -1,6 +1,6 @@
 /*
  * ====================================================================
- * Copyright (c) 2002-2006 The RapidSvn Group.  All rights reserved.
+ * Copyright (c) 2002-2008 The RapidSvn Group.  All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -279,16 +279,6 @@ Utf8ToLocal (const char* srcUtf8);
 wxString
 Utf8ToLocal (const std::string & srcUtf8);
 
-/**
- * converts a filename from utf8
- * to the local encoding and returns
- * this as a @a wxFileName instance
- *
- * @param nameUtf8
- */
-wxFileName
-Utf8ToFileName (const char * nameUtf8);
-
 /**
  * Convert a character array to a wxBitmap.
  * You have to ensure the contents of the array string
